/****************************************************************************
*
*  delay.c
*
****************************************************************************/

#pragma chip PIC16F877

#include "Delay.h"

/***************************************************************************/
/**
*  Delays for a multiple of 100 microseconds.
*
*  @note This routine assumes a 20 MHz clock.
*/

extern void Delay100uSec
(
   uns8 num100uSec   /**< Number of 100 microsecond units to delay         */
)
{
   uns8 inner;

#asm
OLOOP    movlw    D'124'         ;load inner loop counter constant
         movwf    inner          ;load counter

ILOOP    clrwdt                  ;kick the dog
         decfsz   inner,F        ;has inner loop expired?
         goto     ILOOP          ;no, repeat inner loop

         decfsz   num100uSec,F   ;yes, has outer loop expired?
         goto     OLOOP          ;no, repeat outer loop
#endasm

} // Delay100uSec

/***************************************************************************/
/**
*  Delays for a multiple of 10 microseconds.
*
*  @note This routine assumes a 20 MHz clock.
*/

extern void Delay10uSec
(
   uns8 num10uSec    /**< Number of 10 microsecond units to delay         */
)
{
   uns8 inner;

#asm

         ; Outer loop takes 43 + 7 = 50 cycles = 10 uSec

OLOOP    movlw    D'14'          ;load inner loop counter constant
         movwf    inner          ;load counter

         ; Inner loop takes 3 * 14 + 1 = 43 cycles

ILOOP    decfsz   inner,F        ;has inner loop expired?
         goto     ILOOP          ;no, repeat inner loop

         nop
         nop

         decfsz   num10uSec,F    ;yes, has outer loop expired?
         goto     OLOOP          ;no, repeat outer loop
#endasm

} // Delay10uSec

/***************************************************************************/
/**
*  Wait for Timer 0 to rollover
*/

extern void WaitForTimer0Rollover( void )
{
#asm
_WaitForTimer0Rollover:
	clrwdt
	btfss	INTCON,T0IF             // Has rollover occured?
	goto	_WaitForTimer0Rollover  // No - keep looping

	bcf		INTCON,T0IF          // Reset Timer
#endasm

} // WaitForTimer0Rollover


